@@ -3,7 +3,7 @@ use Dancer ':syntax';
 
 use 5.008005;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 use Data::Dumper qw(Dumper);
 use Email::Valid   ();
@@ -717,8 +717,25 @@ sub _set_site_config {
 	}
 }
 
+get '/search.json' => sub {
+	my ($site_name, $site) = _get_site();
 
+	my %params = _clean_params(qw(text));
+	return to_json { error => 'no_search_text' } if not $params{text};
 
+	my $db = _get_db();
+
+	# in each page (last
+	my @history = map { {
+		revision  => $_->revision,
+		timestamp => $_->timestamp,
+		author    => $_->author->name,
+#		filename  => $path,
+	} }
+	$db->resultset('PageHistory')->search( { siteid => $site->id, filename => $params{text} } );
+#	title, body, description, abstract, filename
+
+};
 
 
 true;
